import '../style/team_panel.css';
import {BASE} from "../Constants";
import {Team,TeamInfo,Color,User,Member} from "../model/Team/Team"

export default function TeamPanel({isCoach, team}: {isCoach: boolean, team: Team }){
    return (
        <div>
            <TeamDisplay team={team.info}/>

            {isCoach && <CoachOptions id={team.info.id}/>}

            <div>
                <h2>Membres :</h2>
                <MembersDisplay members={team.members}/>
            </div>
        </div>
    )
}

function TeamDisplay({ team}: {team : TeamInfo}) {
    return (
        <div>
            <div>
                <h1>{team.name}</h1>
                <img src={team.picture} alt="Logo d'équipe" />
            </div>
            <div id="colors">
                <p>Couleur principale</p>
                <ColorDisplay color={team.mainColor.hex}/>
                <p>Couleur secondaire</p>
                <ColorDisplay color={team.secondColor.hex}/>
            </div>
        </div>
    )
}

function ColorDisplay({color}: {color : string}){
    return(
        <div className="square" style={{backgroundColor: color}}/>
    )
}

function CoachOptions ({id}:{id:number}){
    return (
        <div>
            <button id="delete" onClick={()=>confirm('Êtes-vous sûr de supprimer cette équipe?') ? window.location.href=`${BASE}/team/${id}/delete` : {}}>Supprimer</button>
        </div>
    )
}

function MembersDisplay({members}:{members : Member[]}){
    const listMember = members.map((member) =>
        <MemberDisplay member={member}/>
    );
    return (
        <div>
            {listMember}
        </div>
    )
}

function MemberDisplay({member}: {member : Member}){
    return (
        <div>
            <img src={member.user.profilePicture} alt="Photo de profile"/>
            <p>{member.user.name}</p>
            <p>{member.role}</p>
            <p>{member.user.email}</p>
        </div>
    )
}
